@@ -5,3 +5,5 @@ from .transformers import ColSelector, TypeCaster, \
     OrdinalEncoder, NanImputer, NullishToNan, OutlierTrimmer, \
     OnehotEncoder, StdScaler, MinMaxScaler, BoxCoxTransformer, \
     PipeMerger 
+from .plot import ts_outlier_plot, separability_plot, \
+    correl_plot, univariate_plot, qq_plot
\ No newline at end of file
